Documentation
¶
Overview ¶
Package graphjson saves and loads architectures to and from graph json files
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Enabled bool
Enabled is set via command line flags to turn on json logging
Functions ¶
func Setup ¶
func Setup(arch string)
Setup by opening the "arch".json file and writing a header, noting the generated architecture type, version and args for the run
Types ¶
type EdgeV0r3 ¶
type EdgeV0r3 struct {
Edge string `json:"edge"`
Source string `json:"source"`
Target string `json:"target"`
}
EdgeV0r3 defines an edge for version 0.3, used to make json edges for writing
type ElementV0r3 ¶
type ElementV0r3 struct {
Node string `json:"node,omitempty"`
Service string `json:"service,omitempty"`
Edge string `json:"edge,omitempty"`
Source string `json:"source,omitempty"`
Target string `json:"target,omitempty"`
}
ElementV0r3 defines a way to read either a node or an edge in the graph for version 0.3
type GraphV0r3 ¶
type GraphV0r3 struct {
Arch string `json:"arch"`
Version string `json:"version"`
Args string `json:"args"`
Graph []ElementV0r3 `json:"graph"`
}
GraphV0r3 defines version 0.3 of the graphjson file format with an array of elements
type GraphVersion ¶
type GraphVersion struct {
Version string `json:"version"`
}
GraphVersion extracts the version so it can be checked
Click to show internal directories.
Click to hide internal directories.